--[[

Interface: 1.4.4.0 1.4.4RC8

Author: GtX | Andy
Date: 18.07.2017
Version: 1.0

Support: http://ls-modcompany.com

History:
V 1.0 @ 18.07.2017 - Beta Release
V 1.1 @ 24.07.2017 - Fixed bug where incorrect status was displayed if more than one item was in use.

About: 
Ability to operate all IC controls using outdoor triggers. If you wish to add a different input binding for each trigger then you can do this as seen in the example below.

Example for xml.

<icExternalAccess>
	<component triggerNode="0>17|0" icIndex="1" triggerRange="1.0" inputBinding="LEFTDOOR" renderScreenText="true" />
	<component triggerNode="0>17|1" icIndex="2" triggerRange="1.0" />
</icExternalAccess>


Example for modDesc.

<l10n>
	<text name="input_EXTERNAL_IC">
        <en>Activate/Deactivate IC</en>
		<de>anschalten/ausschalten (IC)</de>
    </text>
</l10n>

<inputBindings>
	<input name="EXTERNAL_IC"	category="ONFOOT"	key1="KEY_o"	key2="" button="" 	device="0"	 mouse="" />
	<input name="LEFTDOOR"		category="ONFOOT"	key1="KEY_m"	key2="" button="" 	device="0"	 mouse="" />
</inputBindings>

<specializations>
	<specialization name="interactiveExternal"		className="InteractiveExternal"		filename="scripts/InteractiveExternal.lua" />
</specializations>

]]

InteractiveExternal = {}

InteractiveExternal.modDir = g_currentModDirectory;

function InteractiveExternal.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(InteractiveControl, specializations)
end;

function InteractiveExternal:load(savegame)	

	self.isInRangeForIC = InteractiveExternal.isInRangeForIC

	self.icObjects = {}
	
	local i = 0
	
    while true do
		local ic = string.format("vehicle.icExternalAccess.component(%d)", i)
		if not hasXMLProperty(self.xmlFile, ic) then
            break
        end;
		
		local eic = {}
		eic.index = Utils.indexToObject(self.components, getXMLString(self.xmlFile, ic.."#triggerNode"))
		eic.minDistance = Utils.getNoNil(getXMLFloat(self.xmlFile, ic.."#triggerRange"), 2.0)
		eic.icIndex = getXMLInt(self.xmlFile, ic.."#icIndex")
		
		eic.input = Utils.getNoNil(getXMLString(self.xmlFile, ic.. "#inputBinding"), "EXTERNAL_IC");
		eic.renderScreenText = Utils.getNoNil(getXMLBool(self.xmlFile, ic.."#renderScreenText"), false)

		table.insert(self.icObjects, eic)
		i = i + 1
		
	end;
end;

function InteractiveExternal:delete()
end;

function InteractiveExternal:mouseEvent(posX, posY, isDown, isUp, button)
end;

function InteractiveExternal:keyEvent(unicode, sym, modifier, isDown)
end;

function InteractiveExternal:update(dt)
	if self.isClient then
		for i=1, table.getn(self.icObjects) do
			local object = self.interactiveObjects[self.icObjects[i].icIndex];
			
			if self:isInRangeForIC(i) then
				if object.isOpen then
					g_currentMission:addHelpButtonText(string.format(object.offMessage, object.name), InputBinding[self.icObjects[i].input]);
					if self.icObjects[i].renderScreenText then
						setTextColor(1.0, 1.0, 1.0, 1.0);
						setTextAlignment(RenderText.ALIGN_CENTER); 				
						renderText(0.5, 0.06, 0.02, string.format(object.offMessage, object.name))
					end
				else
					g_currentMission:addHelpButtonText(string.format(object.onMessage, object.name), InputBinding[self.icObjects[i].input]);
					if self.icObjects[i].renderScreenText then
						setTextColor(1.0, 1.0, 1.0, 1.0);
						setTextAlignment(RenderText.ALIGN_CENTER); 				
						renderText(0.5, 0.06, 0.02, string.format(object.onMessage, object.name))
					end;
				end;	
				
				if InputBinding.hasEvent(InputBinding[self.icObjects[i].input])then
					if object ~= nil then
						object:doAction(true)
					end;
				end;
			end;
		end;
	end;
end;

function InteractiveExternal:draw()
end;

function InteractiveExternal:isInRangeForIC(i)
	local rx, ry, rz = getWorldTranslation(g_currentMission.player.rootNode)
	local ox, oy, oz = getWorldTranslation(self.icObjects[i].index)
	local distance = Utils.vector3Length(rx-ox, ry-oy, rz-oz)

	if distance <= self.icObjects[i].minDistance then
		self.forceIsActive = true
		return true
	else
		self.forceIsActive = false
		return false
	end;
end;